@@ -2,5 +2,7 @@ from .utils.errors import errors
 from .crash import *
 from .mines import *
 from .towers import *
+from .jackpot import *
 from .currency import *
+from .websockets import *
 from .authorization import *
