@@ -1,7 +1,6 @@
-import cloudscraper, websocket, requests, base64, json, time
-from typing import Union, Generator, Any
-from websocket import create_connection
-from random import randbytes
+import cloudscraper, websocket, json, time
+from .authorization import Authorization
+from .websockets import Websocket
 from .utils.errors import errors
 
 scraper = cloudscraper.create_scraper()
@@ -16,6 +15,7 @@ class Round:
         self.private_seed = game["privateSeed"]
         self.private_hash = game["privateHash"]
         self.game_id = game["_id"]
+        self.players = [Authorization.lookup(player["playerID"], player["betAmount"]) for player in game["players"]]
 
 
 class Crash:
@@ -27,23 +27,7 @@ class Crash:
             self.auth = auth
             self._connection = None
 
-        def connect(self, headers: dict = {
-                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:103.0) Gecko/20100101 Firefox/103.0",
-                "Accept": "*/*",
-                "Accept-Language": "en-US,en;q=0.5",
-                "Accept-Encoding": "gzip, deflate, br",
-                "Sec-WebSocket-Version": "13",
-                "Host": "ws.bloxflip.com",
-                "Origin": "https://bloxflip.com",
-                "Sec-WebSocket-Key": str(base64.b64encode(randbytes(16)).decode('utf-8')),
-                "Connection": "keep-alive, Upgrade",
-                "Sec-Fetch-Dest": "websocket",
-                "Sec-Fetch-Mode": "websocket",
-                "Sec-Fetch-Site": "cross-site",
-                "Pragma": "no-cache",
-                "Cache-Control": "no-cache",
-                "Upgrade": "websocket",
-            }) -> websocket.WebSocket:
+        def connect(self, headers: dict = None) -> websocket.WebSocket:
             """Connects to websocket and returns websocket object
             
             Parameters:
@@ -53,11 +37,7 @@ class Crash:
             websocket.WebSocket: A websocket connection connected and already logged in
             """
 
-            self._connection = create_connection(
-                "wss://ws.bloxflip.com/socket.io/?EIO=3&transport=websocket",
-                suppress_origin=True,
-                header=headers
-            )
+            self._connection = Websocket(headers) if headers else Websocket()
 
             ws = self._connection
             ws.send("40/crash,")
@@ -84,7 +64,7 @@ class Crash:
         return self._Websocket(self.auth)
 
     @staticmethod
-    def crashpoints(amount: int = 35, interval: float = 0.01, on_game_start: type(print) = None) -> Generator[list[Union[Round, list[Round]]], Any, Any]:
+    def crashpoints(amount: int = 35, interval: float = 0.01, on_game_start: type(print) = None) -> list:
         """Indefinitely yields the last game's results as well as the previous results everytime a new game starts
         
         Parameters:
@@ -100,14 +80,14 @@ class Crash:
         sent = False
 
         if amount > 35:
-            raise errors.InvalidParamater("Amount cannot be above 35.")
+            raise errors.InvalidParameter("Amount cannot be above 35.")
 
         elif not callable(on_game_start) and on_game_start:
-            raise errors.InvalidParamater("'on_game_start' must be a callable object.")
+            raise errors.InvalidParameter("'on_game_start' must be a callable object.")
 
         while True:
             try:
-                games = scraper.get("https://rest-bf.blox.land/games/crash").json()
+                games = scraper.get("https://api.bloxflip.com/games/crash").json()
             except ValueError:
                 continue
 
@@ -137,10 +117,10 @@ class Crash:
         list: Recent games"""
 
         try:
-            games = scraper.get("https://rest-bf.blox.land/games/crash").json()
-        except:
-            raise errors.NetworkError("A Network Error has occured")
+            games = scraper.get("https://api.bloxflip.com/games/crash").json()
+        except json.decoder.JSONDecodeError:
+            raise errors.NetworkError("A Network Error has occurred.")
 
         history = games["history"]
 
-        return [[Round(_crashpoint) for _crashpoint in history[:amount]]]
\ No newline at end of file
+        return [[Round(_crashpoint) for _crashpoint in history[:amount]]]
