@@ -37,7 +37,7 @@ class Mines:
     def create(self, betamount: float, mines: int) -> None:
         """Creates a mines game"""
 
-        response = scraper.post("https://rest-bf.blox.land/games/mines/create", headers={
+        response = scraper.post("https://api.bloxflip.com/games/mines/create", headers={
                         "x-auth-token": self.auth
                     },
                     json={
@@ -47,7 +47,7 @@ class Mines:
                 )
 
         if betamount < 5:
-            raise errors.InvalidParamater("Bet amount must be greater than 5")
+            raise errors.InvalidParameter("Bet amount must be greater than 5")
 
         if response.status_code == 429:
             raise errors.Ratelimited("Ratelimited: Too many requests")
@@ -60,14 +60,14 @@ class Mines:
             if response.json()["msg"] == "You already have an active mines game!":
                 raise errors.GameAlreadyStarted("You already have an active mines game. End it then try again.")
             if response.json()["msg"] == "You can not afford to start this game!":
-                raise errors.InsuffecientFunds("You cannot afford to start this game.")
+                raise errors.InsufficientFunds("You cannot afford to start this game.")
 
             raise errors.GeneralError("Failed to create game")
 
     def choose(self, choice: int) -> bool:
         """Chooses a tile to bet on"""
 
-        response = scraper.post("https://rest-bf.blox.land/games/mines/action", headers={
+        response = scraper.post("https://api.bloxflip.com/games/mines/action", headers={
                             "x-auth-token": self.auth
                         },
                         json={
@@ -88,7 +88,7 @@ class Mines:
     def cashout(self) -> bool:
         """Cashouts the winnings from the current Mines game"""
 
-        response = scraper.post("https://rest-bf.blox.land/games/mines/action", headers={
+        response = scraper.post("https://api.bloxflip.com/games/mines/action", headers={
                             "x-auth-token": self.auth
                         },
                         json={
